diff --git a/test/multidomain/2cstokes2p2c/test_2cstokes2p2c.cc b/test/multidomain/2cstokes2p2c/test_2cstokes2p2c.cc
index 1f2dc47e19c9e3fe03d31a99653008fda33aa2a5..92207520053ed18b8a741020667a438868a3e680 100644
--- a/test/multidomain/2cstokes2p2c/test_2cstokes2p2c.cc
+++ b/test/multidomain/2cstokes2p2c/test_2cstokes2p2c.cc
@@ -68,12 +68,12 @@ void printUsage(const char *progName, const std::string &errorMsg)
 
 int main(int argc, char** argv)
 {
-#if (HAVE_SUPERLU || HAVE_UMFPACK)
+#if (HAVE_SUPERLU || HAVE_PARDISO)
     typedef TTAG(TwoCStokesTwoPTwoCProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, printUsage);
 #else
-#warning "You need to have SuperLU or UMFPack installed to run this test."
-    std::cerr << "You need to have SuperLU or UMFPack installed to run this test\n";
+#warning "You need to have SuperLU or Pardiso installed to run this test."
+    std::cerr << "You need to have SuperLU or Pardiso installed to run this test\n";
     return 77;
 #endif
 }